Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(743)

Unified Diff: content/browser/renderer_host/media/video_capture_controller_event_handler.h

Issue 13616004: Switch event type when a capture device has been stopped from the render process. This make sure th… (Closed) Base URL: svn://svn.chromium.org/chrome/trunk/src
Patch Set: Addressed code review comments. Created 7 years, 8 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: content/browser/renderer_host/media/video_capture_controller_event_handler.h
diff --git a/content/browser/renderer_host/media/video_capture_controller_event_handler.h b/content/browser/renderer_host/media/video_capture_controller_event_handler.h
index 58f963c73dc73c8ac541e3affe08e5e2eb3d2008..35ab3ef0fe6650ec6861e4802b8abaa385fc1437 100644
--- a/content/browser/renderer_host/media/video_capture_controller_event_handler.h
+++ b/content/browser/renderer_host/media/video_capture_controller_event_handler.h
@@ -45,8 +45,8 @@ class CONTENT_EXPORT VideoCaptureControllerEventHandler {
int height,
int frame_rate) = 0;
- // The capture session has been paused. No more frame will be sent.
- virtual void OnPaused(const VideoCaptureControllerID& id) = 0;
+ // The capture session has ended and no more frames will be sent.
+ virtual void OnEnded(const VideoCaptureControllerID& id) = 0;
protected:
virtual ~VideoCaptureControllerEventHandler() {}

Powered by Google App Engine
This is Rietveld 408576698